==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDSCREENFIELDTYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}TEXTFIELD"/>
 *           &lt;element name="TEXTAREAFIELD" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}NUMERICFIELD"/>
 *           &lt;element name="DATEFIELD" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element name="DATETIMEFIELD" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element name="CHECKBOX" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element name="TIME" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "textfield",
    "textareafield",
    "numericfield",
    "datefield",
    "datetimefield",
    "checkbox",
    "time"
})
@XmlRootElement(name = "USERDEFINEDSCREENFIELDTYPE")
public class USERDEFINEDSCREENFIELDTYPE {

    @XmlElement(name = "TEXTFIELD")
    protected TEXTFIELD_Type textfield;
    @XmlElement(name = "TEXTAREAFIELD")
    protected String textareafield;
    @XmlElement(name = "NUMERICFIELD")
    protected NUMERICFIELD_Type numericfield;
    @XmlElement(name = "DATEFIELD")
    protected String datefield;
    @XmlElement(name = "DATETIMEFIELD")
    protected String datetimefield;
    @XmlElement(name = "CHECKBOX")
    protected String checkbox;
    @XmlElement(name = "TIME")
    protected String time;

    /**
     * Obtient la valeur de la propriété textfield.
     * 
     * @return
     *     possible object is
     *     {@link TEXTFIELD_Type }
     *     
     */
    public TEXTFIELD_Type getTEXTFIELD() {
        return textfield;
    }

    /**
     * Définit la valeur de la propriété textfield.
     * 
     * @param value
     *     allowed object is
     *     {@link TEXTFIELD_Type }
     *     
     */
    public void setTEXTFIELD(TEXTFIELD_Type value) {
        this.textfield = value;
    }

    /**
     * Obtient la valeur de la propriété textareafield.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTEXTAREAFIELD() {
        return textareafield;
    }

    /**
     * Définit la valeur de la propriété textareafield.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTEXTAREAFIELD(String value) {
        this.textareafield = value;
    }

    /**
     * Obtient la valeur de la propriété numericfield.
     * 
     * @return
     *     possible object is
     *     {@link NUMERICFIELD_Type }
     *     
     */
    public NUMERICFIELD_Type getNUMERICFIELD() {
        return numericfield;
    }

    /**
     * Définit la valeur de la propriété numericfield.
     * 
     * @param value
     *     allowed object is
     *     {@link NUMERICFIELD_Type }
     *     
     */
    public void setNUMERICFIELD(NUMERICFIELD_Type value) {
        this.numericfield = value;
    }

    /**
     * Obtient la valeur de la propriété datefield.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATEFIELD() {
        return datefield;
    }

    /**
     * Définit la valeur de la propriété datefield.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATEFIELD(String value) {
        this.datefield = value;
    }

    /**
     * Obtient la valeur de la propriété datetimefield.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATETIMEFIELD() {
        return datetimefield;
    }

    /**
     * Définit la valeur de la propriété datetimefield.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATETIMEFIELD(String value) {
        this.datetimefield = value;
    }

    /**
     * Obtient la valeur de la propriété checkbox.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHECKBOX() {
        return checkbox;
    }

    /**
     * Définit la valeur de la propriété checkbox.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHECKBOX(String value) {
        this.checkbox = value;
    }

    /**
     * Obtient la valeur de la propriété time.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTIME() {
        return time;
    }

    /**
     * Définit la valeur de la propriété time.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTIME(String value) {
        this.time = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDSCREENFIELDTYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}TEXTFIELD"/>
 *           &lt;element name="TEXTAREAFIELD" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}NUMERICFIELD"/>
 *           &lt;element name="DATEFIELD" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element name="DATETIMEFIELD" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element name="CHECKBOX" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           &lt;element name="TIME" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "textfield",
    "textareafield",
    "numericfield",
    "datefield",
    "datetimefield",
    "checkbox",
    "time"
})
@XmlRootElement(name = "USERDEFINEDSCREENFIELDTYPE")
public class USERDEFINEDSCREENFIELDTYPE {

    @XmlElement(name = "TEXTFIELD")
    protected TEXTFIELD_Type textfield;
    @XmlElement(name = "TEXTAREAFIELD")
    protected String textareafield;
    @XmlElement(name = "NUMERICFIELD")
    protected NUMERICFIELD_Type numericfield;
    @XmlElement(name = "DATEFIELD")
    protected String datefield;
    @XmlElement(name = "DATETIMEFIELD")
    protected String datetimefield;
    @XmlElement(name = "CHECKBOX")
    protected String checkbox;
    @XmlElement(name = "TIME")
    protected String time;

    /**
     * Gets the value of the textfield property.
     * 
     * @return
     *     possible object is
     *     {@link TEXTFIELD_Type }
     *     
     */
    public TEXTFIELD_Type getTEXTFIELD() {
        return textfield;
    }

    /**
     * Sets the value of the textfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link TEXTFIELD_Type }
     *     
     */
    public void setTEXTFIELD(TEXTFIELD_Type value) {
        this.textfield = value;
    }

    /**
     * Gets the value of the textareafield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTEXTAREAFIELD() {
        return textareafield;
    }

    /**
     * Sets the value of the textareafield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTEXTAREAFIELD(String value) {
        this.textareafield = value;
    }

    /**
     * Gets the value of the numericfield property.
     * 
     * @return
     *     possible object is
     *     {@link NUMERICFIELD_Type }
     *     
     */
    public NUMERICFIELD_Type getNUMERICFIELD() {
        return numericfield;
    }

    /**
     * Sets the value of the numericfield property.
     * 
     * @param value
     *     allowed object is
     *     {@link NUMERICFIELD_Type }
     *     
     */
    public void setNUMERICFIELD(NUMERICFIELD_Type value) {
        this.numericfield = value;
    }

    /**
     * Gets the value of the datefield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATEFIELD() {
        return datefield;
    }

    /**
     * Sets the value of the datefield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATEFIELD(String value) {
        this.datefield = value;
    }

    /**
     * Gets the value of the datetimefield property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATETIMEFIELD() {
        return datetimefield;
    }

    /**
     * Sets the value of the datetimefield property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATETIMEFIELD(String value) {
        this.datetimefield = value;
    }

    /**
     * Gets the value of the checkbox property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHECKBOX() {
        return checkbox;
    }

    /**
     * Sets the value of the checkbox property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHECKBOX(String value) {
        this.checkbox = value;
    }

    /**
     * Gets the value of the time property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTIME() {
        return time;
    }

    /**
     * Sets the value of the time property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTIME(String value) {
        this.time = value;
    }

}
